==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/Image.java <==
package com.xforceplus.elephant.entity;

import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Image implements Serializable {

  private static final long serialVersionUID=1L;

  private String imageType;

  private String imageSource;

  private String requireOcrFlag;

  private String fileUrl;

  private String fileUrlHandle;

  private String fileUrlOrigin;

  private String fileType;

  private String fileTypeHandle;

  private String fileOrder;

  private Long fileLevel;

  private String recStatus;

  private String taskId;

  private Long copyCount;

  private LocalDateTime recStartTime;

  private LocalDateTime recEndTime;

  private Long billImageId;

  private Long ticketImageId;

  private String status;

  private String isManualUnhook;

  private String isPublic;

  private String exceptionStatus;

  private String returnStatus;

  private String batchNo;

  private String imageCategory;

  private String returnReason;

  private String returnRemark;

  private String reserved1;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String billCode;

  private String reserved2;

  private String reserved3;

  private String fileUrlLocal;

  private String isReuse;

  private String pageCode;

  private String billEntityCode;

  private String createUserCode;

  private String moreFileUrl;

  private String tenantCode;

  private Long imageManyToOneBaseBillId;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/Image.java <==
package com.xforceplus.elephant.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Image implements Serializable {

  private static final long serialVersionUID=1L;

  private String imageType;

  private String imageSource;

  private String requireOcrFlag;

  private String fileUrl;

  private String fileUrlHandle;

  private String fileUrlOrigin;

  private String fileType;

  private String fileTypeHandle;

  private String fileOrder;

  private Long fileLevel;

  private String recStatus;

  private String taskId;

  private Long copyCount;

  private LocalDateTime recStartTime;

  private LocalDateTime recEndTime;

  private Long billImageId;

  private Long ticketImageId;

  private String status;

  private String isManualUnhook;

  private String isPublic;

  private String exceptionStatus;

  private String returnStatus;

  private String batchNo;

  private String imageCategory;

  private String returnReason;

  private String returnRemark;

  private String reserved1;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String billCode;

  private String reserved2;

  private String reserved3;

  private String fileUrlLocal;

  private String isReuse;

  private String pageCode;

  private String billEntityCode;

  private String createUserCode;

  private String moreFileUrl;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  private String isIssued;

  private String exceptionInfo;

  private String warningInfo;

  private String relExceptionInfo;

  private String relWarningInfo;

  private String isCommit;

  private Long commitUserId;

  private String commitUserName;

  private LocalDateTime commitTime;

  private String isHang;

  private String returnType;

  private Long imageManyToOneBaseBillId;

  private Long billOneToManyImageId;




        }
